@@ -27,11 +27,12 @@ import types
 import pandas as pd
 from botocore.client import Config
 import ibm_boto3
+from datetime import datetime
 
 
 class SQLQuery():
     def __init__(self, api_key, instance_crn, target_cos_url, client_info=''):
-        endpoint_alias_mapping = {
+        self.endpoint_alias_mapping = {
             "us-geo": "s3-api.us-geo.objectstorage.softlayer.net",
             "dal": "s3-api.dal-us-geo.objectstorage.softlayer.net",
             "wdc": "s3-api.wdc-us-geo.objectstorage.softlayer.net",
@@ -47,7 +48,7 @@ class SQLQuery():
         self.instance_crn = instance_crn
         self.target_cos = target_cos_url
         provided_cos_endpoint = target_cos_url.split("/")[2]
-        self.target_cos_endpoint = endpoint_alias_mapping.get(provided_cos_endpoint, provided_cos_endpoint)
+        self.target_cos_endpoint = self.endpoint_alias_mapping.get(provided_cos_endpoint, provided_cos_endpoint)
         self.target_cos_bucket = target_cos_url.split("/")[3]
         self.target_cos_prefix = target_cos_url[target_cos_url.replace('/', 'X', 3).find('/')+1:]
         if self.target_cos_endpoint == '' or self.target_cos_bucket == '' or self.target_cos_prefix == target_cos_url:
@@ -135,7 +136,7 @@ class SQLQuery():
             else:
                 print("Job status check failed with http code {}".format(response.code))
                 break
-            time.sleep(1)
+            time.sleep(2)
         return jobStatus
 
     def __iter__(self):
@@ -152,13 +153,13 @@ class SQLQuery():
         elif job_status != 'completed':
             raise ValueError('SQL job with jobId {} did not finish successfully. No result available.')
 
-        if self.target_cos_prefix != '':
+        if self.target_cos_prefix != '' and not self.target_cos_prefix.endswith('/'):
             result_location = "https://{}/{}?prefix={}/jobid={}/part".format(self.target_cos_endpoint,
                                                                         self.target_cos_bucket, self.target_cos_prefix,
                                                                         jobId)
         else:
-            result_location = "https://{}/{}?prefix=jobid={}/part".format(self.target_cos_endpoint,
-                                                                        self.target_cos_bucket,
+            result_location = "https://{}/{}?prefix={}jobid={}/part".format(self.target_cos_endpoint,
+                                                                        self.target_cos_bucket, self.target_cos_prefix,
                                                                         jobId)
 
         response = self.client.fetch(
@@ -289,6 +290,9 @@ class SQLQuery():
                     error = None
                     if 'error' in job_details:
                         error = job_details['error']
+                        end_time = None
+                    else:
+                        end_time = job_details['end_time']
                     error_message = None
                     if 'error_message' in job_details:
                         error_message = job_details['error_message']
@@ -298,7 +302,7 @@ class SQLQuery():
                                                        'statement': job_details['statement'],
                                                        'resultset_location': job_details['resultset_location'],
                                                        'submit_time': job_details['submit_time'],
-                                                       'end_time': job_details['end_time'],
+                                                       'end_time': end_time,
                                                        'error': error,
                                                        'error_message': error_message,
                                                        }], ignore_index=True)
@@ -334,3 +338,70 @@ class SQLQuery():
         else:
             print ("https://sql.ng.bluemix.net/sqlquery/?instance_crn={}".format(
                 urllib.unquote(self.instance_crn).decode('utf8')))
+
+    def get_cos_summary(self, url):
+        def sizeof_fmt(num, suffix='B'):
+            for unit in ['', 'K', 'M', 'G', 'T', 'P', 'E', 'Z']:
+                if abs(num) < 1024.0:
+                    return "%3.1f %s%s" % (num, unit, suffix)
+                num /= 1024.0
+            return "%.1f %s%s" % (num, 'Y', suffix)
+
+        if not self.logged_on:
+            print("You are not logged on to IBM Cloud")
+            return
+
+        endpoint = url.split("/")[2]
+        endpoint = self.endpoint_alias_mapping.get(endpoint, endpoint)
+        bucket = url.split("/")[3]
+        prefix = url[url.replace('/', 'X', 3).find('/') + 1:]
+
+        cos_client = ibm_boto3.client(service_name='s3',
+                                      ibm_api_key_id=self.api_key,
+                                      ibm_auth_endpoint="https://iam.ng.bluemix.net/oidc/token",
+                                      config=Config(signature_version='oauth'),
+                                      endpoint_url='https://' + endpoint)
+
+        paginator = cos_client.get_paginator("list_objects")
+        page_iterator = paginator.paginate(Bucket=bucket, Prefix=prefix)
+
+        total_size = 0
+        smallest_size = 9999999999999999
+        largest_size = 0
+        count = 0
+        oldest_modification = datetime.max.replace(tzinfo=None)
+        newest_modification = datetime.min.replace(tzinfo=None)
+        smallest_object = None
+        largest_object = None
+
+        for page in page_iterator:
+            if "Contents" in page:
+                for key in page['Contents']:
+                    size = int(key["Size"])
+                    total_size += size
+                    if size < smallest_size:
+                        smallest_size = size
+                        smallest_object = key["Key"]
+                    if size > largest_size:
+                        largest_size = size
+                        largest_object = key["Key"]
+                    count += 1
+                    modified = key['LastModified'].replace(tzinfo=None)
+                    if modified < oldest_modification:
+                        oldest_modification = modified
+                    if modified > newest_modification:
+                        newest_modification = modified
+
+        if count == 0:
+            smallest_size=None
+            oldest_modification=None
+            newest_modification=None
+        else:
+            oldest_modification = oldest_modification.strftime("%B %d, %Y, %HH:%MM:%SS")
+            newest_modification = newest_modification.strftime("%B %d, %Y, %HH:%MM:%SS")
+
+        return {'url': url, 'total_objects': count, 'total_volume': sizeof_fmt(total_size),
+                'oldest_object_timestamp': oldest_modification,
+                'newest_object_timestamp': newest_modification,
+                'smallest_object_size': sizeof_fmt(smallest_size), 'smallest_object': smallest_object,
+                'largest_object_size': sizeof_fmt(largest_size), 'largest_object': largest_object}
