@@ -4,7 +4,6 @@ my_instance_crn='crn%3Av1%3Abluemix%3Apublic%3Asql-query%3Aus-south%3Aa%2Fd86af7
 my_target_cos_url='cos://us-south/sqltempregional/'
 sqlClient = ibmcloudsql.SQLQuery(my_bluemix_apikey, my_instance_crn, my_target_cos_url, client_info='ibmcloudsql test')
 
-
 print("Running test with SQL grammar error:")
 sqlClient.run_sql("SELECT xyzFROM cos://us-geo/sql/employees.parquet STORED AS PARQUET LIMIT 10")
 
@@ -41,3 +40,6 @@ sqlClient.sql_ui_link()
 
 print("Job list:")
 sqlClient.get_jobs().head(200)
+
+print("COS Summary:")
+sqlClient.get_cos_summary("cos://us-south/cloudant-access-logs-us-south/cloudant-access-logs/dt=2018-02-02")
